==> haskell-conduit-combinators-1.1.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.1.1
id: conduit-combinators-1.1.1-FlHUWVaA3Yl649vddSDPfm
key: conduit-combinators-1.1.1-FlHUWVaA3Yl649vddSDPfm
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: 0199a52358bf28575be5a83f4f2ba7a9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/conduit-combinators-1.1.1
hs-libraries: HSconduit-combinators-1.1.1-FlHUWVaA3Yl649vddSDPfm
depends:
    base-4.9.0.0 base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 chunked-data-0.3.0-LS23mPdosPIDUMD34hvMOB
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS filepath-1.4.1.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.2-K5Z4ktfMwTB7vAbcHSGylk
    mwc-random-0.13.5.0-JV0Fije0tjpAZxTL84rKQ4
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4 unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    void-0.7.2-Gq1uNTFl2JaJr51CTc0tGb
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-combinators-1.1.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.1.1
id: conduit-combinators-1.1.1-8hiZQvV7qtC5GudCzdkIAc
key: conduit-combinators-1.1.1-8hiZQvV7qtC5GudCzdkIAc
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: 30e9b8b2d7397794135c3349c1642fcd
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-combinators-1.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/conduit-combinators-1.1.1
hs-libraries: HSconduit-combinators-1.1.1-8hiZQvV7qtC5GudCzdkIAc
depends:
    base-4.9.0.0 base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 chunked-data-0.3.0-LS23mPdosPIDUMD34hvMOB
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS filepath-1.4.1.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.2-K5Z4ktfMwTB7vAbcHSGylk
    mwc-random-0.13.6.0-FkwmwAh2ZNWGdUe7qkQMIm
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4 unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    void-0.7.2-Gq1uNTFl2JaJr51CTc0tGb
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
